@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::AUTHORITY = 'cpan:JANDREW';
 }
-use version 0.77; our $VERSION = qv('v0.34.6');
+use version 0.77; our $VERSION = qv('v0.36.12');
 
 use 5.010;
 use	List::Util 1.33;
@@ -899,6 +899,30 @@ __END__
 
 Spreadsheet::XLSX::Reader::LibXML - Read xlsx spreadsheet files with LibXML
 
+=head3 version
+
+v0.36.12
+
+=begin html
+
+<h3>
+	<a id="user-content-badges" class="anchor" href="#badges" aria-hidden="true">
+		<!-- <span class="octicon octicon-link"></span></a> -->
+		<a href="#___top" title="click to go to top of document" name="user-content-badges">badges</a>
+</h3>
+
+<a href="https://travis-ci.org/jandrew/Spreadsheet-XLSX-Reader-LibXML"><img alt="Build Status" src="https://travis-ci.org/jandrew/Spreadsheet-XLSX-Reader-LibXML.png?branch=master" alt='Travis Build'/></a>
+
+<a href='https://coveralls.io/r/jandrew/Spreadsheet-XLSX-Reader-LibXML?branch=master'><img src='https://coveralls.io/repos/jandrew/Spreadsheet-XLSX-Reader-LibXML/badge.svg?branch=master' alt='Coverage Status' /></a>
+
+<a href="https://www.perl.org"><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="perl version"></a>
+
+<a href="http://badge.fury.io/pl/Spreadsheet-XLSX-Reader-LibXML"><img src="https://badge.fury.io/pl/Spreadsheet-XLSX-Reader-LibXML.svg" alt="CPAN version" height="20"></a>
+
+<a href='http://cpants.cpanauthors.org/dist/Spreadsheet-XLSX-Reader-LibXML'><img src='http://cpants.cpanauthors.org/dist/Spreadsheet-XLSX-Reader-LibXML.png' alt='kwalitee' height="20"/></a>
+
+=end html
+
 =head1 SYNOPSIS
 
 The following uses the 'TestBook.xlsx' file found in the t/test_files/ folder
@@ -2085,24 +2109,40 @@ L<group_return_type|/group_return_type> => 'value'
 
 =head1 BUILD / INSTALL from Source
 
-B<1.> Ensure that you have the libxml2 B<and libxml2-devel> libraries installed using 
-your favorite system package installer.  One way to check if it is already installed 
-is to attempt to install L<XML::LibXML> separatly with cpan.
+B<0.> Please note that using L<cpanm|https://metacpan.org/pod/App::cpanminus> is much easier 
+than a source build! (but it will not always give the latest github version)
+
+	cpanm Spreadsheet-XLSX-Reader-LibXML
+
+B<1.> This package uses L<Alien::LibXML> to try and ensure that the mandatory prerequisite 
+L<XML::LibXML> will load.  The biggest gotcha here is that older (<5.20.0.2) versions of 
+Strawberry Perl and some other Win32 perls may not support the script 'pkg-config' which is 
+required.  You can resolve this by installation L<PkgConfig> as 'pkg-config'.  I have 
+included the short version of that process below but download the full L<PkgConfig> distribution 
+and read README.win32 file for other options and much more explanation.
 
 =over
 
-L<http://xmlsoft.org/>
+B<this will conflict with any existing pkg-config installed>
 
+	C:\> cpanm PkgConfig --configure-args=--script=pkg-config
+	
 =back
+
+It may be that you still need to use a system package manager to L<load|http://xmlsoft.org/> the 
+'libxml2-devel' library.  If this is the case or you experience any other installation issues please 
+L<submit them to github|https://github.com/jandrew/Spreadsheet-XLSX-Reader-LibXML/issues> especially 
+if they occur prior to starting the test suit as these failures will not auto push from CPAN Testers 
+so I won't know to fix them!
 	
 B<2.> Download a compressed file with this package code from your favorite source
 
 =over
 
-L<Meta::CPAN|https://metacpan.org/pod/Spreadsheet::XLSX::Reader::LibXML>
-
 L<github|https://github.com/jandrew/Spreadsheet-XLSX-Reader-LibXML>
 
+L<Meta::CPAN|https://metacpan.org/pod/Spreadsheet::XLSX::Reader::LibXML>
+
 L<CPAN|http://search.cpan.org/~jandrew/Spreadsheet-XLSX-Reader-LibXML/>
 
 =back
@@ -2179,9 +2219,6 @@ B<5.> Build a DOM parser alternative for the sheets
 
 =back
 
-B<6.> Make L</empty_is_end> finish a sheet for rows with formatting but no data.  
-Possibly this requires an additional attribute 'next_ignores_empty'?
-
 =back
 
 =head1 AUTHOR
@@ -2207,6 +2244,8 @@ L<Frank Maas|https://github.com/Frank071>
 
 L<Stuart Watt|https://github.com/morungos>
 
+L<Toby Inkster|https://github.com/morungos>
+
 =back
 
 =head1 COPYRIGHT
@@ -2259,11 +2298,11 @@ L<version> - 0.077
 
 =over
 
-L<Spreadsheet::ParseExcel> - Excel 2003 and earlier
+L<Spreadsheet::ParseExcel> - Excel version 2003 and earlier
 
-L<Spreadsheet::XLSX> - 2007+
+L<Spreadsheet::XLSX> - Excel version 2007 and later
 
-L<Spreadsheet::ParseXLSX> - 2007+
+L<Spreadsheet::ParseXLSX> - Excel version 2007 and later
 
 L<Log::Shiras|https://github.com/jandrew/Log-Shiras>
 
